[![PyPI](https://img.shields.io/pypi/v/cliboa?style=flat-square)](https://pypi.org/project/cliboa)
[![PyPI - Implementation](https://img.shields.io/pypi/implementation/cliboa?style=flat-square)](https://pypi.org/project/cliboa)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cliboa?style=flat-square)](https://pypi.org/project/cliboa)
[![GitHub Actions](https://github.com/BrainPad/cliboa/actions/workflows/test.yaml/badge.svg)](https://github.com/BrainPad/cliboa/actions/workflows/test.yaml)
[![Code Style:
black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)
[![Contributions Welcome](https://img.shields.io/static/v1.svg?label=Contributions&message=Welcome&color=0059b3&style=flat-square)](https://github.com/BrainPad/cliboa/blob/master/CONTRIBUTING.md)
[![Repo Size](https://img.shields.io/github/repo-size/BrainPad/cliboa)](https://github.com/BrainPad/cliboa)

# Table of Contents
* [Introduction](#introduction)
  * [What is cliboa](#what-is-cliboa)
  * [Features](#features)
* [Documentation](#documentation)

# Introduction

## What is cliboa

**cliboa** is an application framework designed for building ETL/ELT pipelines.
It streamlines the entire process of fetching, transforming, and transferring data between various databases, cloud storage, and other services.
![](/img/cliboa_brief.png)

## Features
- **Python based framework**: Leverage the power and flexibility of Python.
- **YAML-based configuration**: Define and execute complex ETL/ELT workflows with simple, human-readable YAML files.
- **Highly extensible**: Easily implement custom modules in just a few steps if the built-in modules don't meet your specific needs.

# Documentation

> [!NOTE]
> **cliboa v3 has been released!**
> With the release of v3, official support for v2 has ended. We recommend all users to migrate to v3.

* [QuickStart](/docs/quick_start.md)
* [MANUAL](/docs/manual.md)
  * [Scenario Configuration](/docs/scenario_configuration.md)
  * [Default ETL Modules](/docs/default_etl_modules.md)
  * [Migration Guide from v2 to v3](/docs/migration_v2_to_v3.md)
* [How to Contribute](/CONTRIBUTING.md)
* [Developer Documents](/docs/developers/)
